@@ -1,16 +1,13 @@
 use strict;
 use warnings;
 package IPC::Lockfile;
-$IPC::Lockfile::VERSION = '0.02';
+$IPC::Lockfile::VERSION = '0.03';
 # ABSTRACT: run only one instance of a program at a time using flock
 use Fcntl qw(:flock);
 
-my $filepath = "$0.lock";
-
 # lexical filehandles dont work!
-open LOCKFILE, '>', $filepath
-  or die "Unable to create the lockfile $filepath $!\n";
-flock LOCKFILE, LOCK_EX|LOCK_NB or die "$0 is running!\n";;
+open LOCKFILE, '<', $0  or die "Unable to create the lockfile $0 $!\n";
+flock LOCKFILE, LOCK_EX|LOCK_NB or die "$0 is running!\n";
 
 
 1;
@@ -27,7 +24,7 @@ IPC::Lockfile - run only one instance of a program at a time using flock
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -38,16 +35,8 @@ Just import the module:
 
     ... # program code here
 
-This will create a lockfile in the same directory as the program. To avoid
-race conditions, the file will not be deleted when the program ends.
-
-Or do not use this module and just add these two lines to your program:
-
-  use Fcntl qw(:flock);
-  flock DATA, LOCK_EX|LOCK_NB or die "$0 is running!\n";;
-
-No external lockfile is created as it uses C<_DATA_>. An elegant L<solution|http://perl.plover.com/yak/flock/samples/slide006.html>
-for lockfiles proposed by Mark Jason Dominus.
+This will open a lock on the program file, avoiding the need for an external
+lockfile. This elegant L<solution|http://perl.plover.com/yak/flock/samples/slide006.html> for lockfiles was proposed by Mark Jason Dominus.
 
 =head1 DESCRIPTION
 
